stl

package
v0.0.0-...-0ac7fff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2026 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Overview

Package stl provides the data structures for the speedtestlogger app

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Entry

type Entry struct {

	// Id of Entry
	Id int64

	// Seconds since Jan 1 1970 GMT
	Ts int64

	// Download speed in megabits per second
	DownloadMbps float64

	// Upload speed in megabits per second
	UploadMbps float64
}

Entry represents a speed test data point

Directories

Path Synopsis
Package aggregators aggregates values.
Package aggregators aggregates values.
Package dates contains routines for converting between dates and timestamps.
Package dates contains routines for converting between dates and timestamps.
Package format provides formatting routines for speedtestlogger app.
Package format provides formatting routines for speedtestlogger app.
Package stldb handles storing instances in the speedtestlogger app to persistent storage.
Package stldb handles storing instances in the speedtestlogger app to persistent storage.
fixture
Package fixture provides test suites to test implementations of the datastore interfaces in the stldb package.
Package fixture provides test suites to test implementations of the datastore interfaces in the stldb package.
for_sqlite
Package for_sqlite provides a sqlite implementation of interfaces in the stldb package.
Package for_sqlite provides a sqlite implementation of interfaces in the stldb package.
sqlite_setup
Package sqlite_setup sets up a sqlite database for the speedtestlogger app
Package sqlite_setup sets up a sqlite database for the speedtestlogger app

Jump to